# py2pyd

**py2pyd** is a fully cross-platform CLI tool, to compile Python scripts (`.py`) into `.pyd` shared library on **Windows** or
 `.so` on **Linux**, with only the `.py` file to compile as argument.

**Installation**
`bash|cmd :`
```bash|cmd

pip install py2pyd

```

**Usage:**

To compile a Python file to a `.pyd` shared library on Windows
 or `.so` on Linux:

```python

py2pyd myscript.py

```

**output:**

The compiled `.pyd` or `.so` shared library

